@@ -27,8 +27,9 @@ class Agent(object):
         raise Exception("credentials are tampered due to different hmac")
 
     def get(self, id: str, pw: str, k: str) -> Any:
-        return self.__decrypt(Broker(app_name=self.__app_name, username=mac(id, self.__hmac_key)+mac(pw, self.__hmac_key))
-                              .get(mac(k, self.__hmac_key)))
+        return self.__decrypt(
+            Broker(app_name=self.__app_name, username=mac(id, self.__hmac_key)+mac(pw, self.__hmac_key))
+            .get(mac(k, self.__hmac_key)))
 
 
 
